redvox.cloud.routes API documentation
Description: This module contains the route definitions for interacting with the RedVox Cloud API.

# Module `redvox.cloud.routes`

This module contains the route definitions for interacting with the RedVox Cloud API.

Expand source code

    """
    This module contains the route definitions for interacting with the RedVox Cloud API.
    """

    class RoutesV1:
        """
        Route definitions for version 1 of the RedVox Cloud API.
        """

        HEALTH_CHECK: str = "/"
        AUTH_USER: str = "/api/v1/auth"
        VALIDATE_TOKEN: str = "/api/v1/auth/token"
        REFRESH_TOKEN: str = "/api/v1/auth/refresh"
        METADATA_REQ: str = "/api/v1/metadata"
        METADATA_REQ_M: str = "/api/v1/metadata/m"
        TIMING_METADATA_REQ: str = "/api/v1/metadata/timing"
        STATION_STATUS_TIMELINE: str = "/api/v1/metadata/timeline"
        DATA_RANGE_REQ: str = "/api/v1/data/range"
        DATA_RANGE_REQ_M: str = "/api/v1/data/range/m"
        DATA_REPORT_REQ: str = "/api/v1/data/report"
        STATION_STATS: str = "/api/v1/metadata/stats"

## Classes

`class RoutesV1`

  Route definitions for version 1 of the RedVox Cloud API.

  Expand source code

      class RoutesV1:
          """
          Route definitions for version 1 of the RedVox Cloud API.
          """

          HEALTH_CHECK: str = "/"
          AUTH_USER: str = "/api/v1/auth"
          VALIDATE_TOKEN: str = "/api/v1/auth/token"
          REFRESH_TOKEN: str = "/api/v1/auth/refresh"
          METADATA_REQ: str = "/api/v1/metadata"
          METADATA_REQ_M: str = "/api/v1/metadata/m"
          TIMING_METADATA_REQ: str = "/api/v1/metadata/timing"
          STATION_STATUS_TIMELINE: str = "/api/v1/metadata/timeline"
          DATA_RANGE_REQ: str = "/api/v1/data/range"
          DATA_RANGE_REQ_M: str = "/api/v1/data/range/m"
          DATA_REPORT_REQ: str = "/api/v1/data/report"
          STATION_STATS: str = "/api/v1/metadata/stats"

  ### Class variables

  `var AUTH_USER : str`
  `var DATA_RANGE_REQ : str`
  `var DATA_RANGE_REQ_M : str`
  `var DATA_REPORT_REQ : str`
  `var HEALTH_CHECK : str`
  `var METADATA_REQ : str`
  `var METADATA_REQ_M : str`
  `var REFRESH_TOKEN : str`
  `var STATION_STATS : str`
  `var STATION_STATUS_TIMELINE : str`
  `var TIMING_METADATA_REQ : str`
  `var VALIDATE_TOKEN : str`